unit Video;

interface



uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, dialogs, stdctrls,
  ExtCtrls,avicap,mmsystem,dsgnintf;


// Types for event-procedures
type
  TCapStatusProc = procedure(Sender: TObject) of object;
  TCapStatusCallback = procedure (Sender:TObject;nID:integer;status:string) of object;
  TVideoStream = procedure (sender:TObject;lpVhdr:PVIDEOHDR) of object;
  TAudioStream = procedure (sender:TObject;lpWHdr:PWAVEHDR) of object;

// Property Editor for driver selection
type TDrivereditor= class (TPropertyEditor)
  function GetAttributes:TPropertyAttributes;override;
  procedure GetValues(Proc: TGetStrProc);override;
  function GetValue:string;override;
  procedure SetValue(const Value: string);override;
end;


type
  TVideo = class(TCustomControl)
  private
   fdriverIndex:integer;   // Videodriver index
   fVideoDriverName     : string;  // name of videodriver
   fhCapWnd             : THandle;  // handle for CAP-Window
   fpDrivercaps         : PCapDriverCaps; // propertys of videodriver
   fpDriverStatus       : pCapStatus; // status of capdriver
   fscale               : boolean;  // window scaling
   fprop                : boolean;  // proportional scaling
   fpreviewrate         : word;  // Frames p. sec during preview
   fmicrosecpframe      : cardinal; // framerate as microsconds
   fCapVideoFileName       : string;
   fCapSingleImageFileName : string;
   fcapAudio               :boolean;
   fcapTimeLimit           :word;
   fIndexSize             :cardinal;
   fcapToFile             : boolean;

   fCapStatusProcedure     : TCapStatusProc;
   fcapStatusCallBack      : TCapStatusCallback;
   fcapVideoStream         : TVideoStream;
   fcapAudioStream         : TAudiostream;


   procedure setsize(var msg:TMessage); message WM_SIZE;  // Changing size of cap window
   function GetDriverCaps:boolean;                        // get driver capitiyties
   procedure DeleteDriverProps;                           // delete driver capitilyites
   function GetDriverStatus(callback:boolean):boolean; // Treiberstatus abfagen
   Procedure SetDriverOpen(value:boolean) ;         // ffnen/ Schlieen  des Treibers
   function GetDriverOpen:boolean;                        // Treieber Geffnet ?
   function GetPreview:boolean;   // fenster im Prview Modus
   function GetOverlay:Boolean;   // Fenster im Overlay Modus;
   procedure SizeCap;             //  Neuberechung Cap-Fenstegre
   procedure Setprop(value:Boolean); // Proportionalstecken einstellen
   procedure SetMicroSecPerFrame(value:cardinal);
   procedure setFrameRate(value:word);
   function  GetFrameRate:word;


   procedure SetDriverName(value:String); // Treibername Setzen index Bestimmen
   procedure SetDriverIndex(value:integer);// Treiber index festlegen
   function CreateCapWindow:boolean;       // Treiber ffnen Cap-Window Erzeugen
   procedure DestroyCapwindow;             // Treiber schlieen Cap-Window Zerstren
    function GetCapWidth:word;              // Hhe und Breite des Videoformates
    function GetCapHeight:word;
    function  GetHasDlgVFormat  : Boolean;  // Hat einen Format-Dialog
    function  GetHasDlgVDisplay : Boolean;  // Hat einen Display Dialog
    function  GetHasDlgVSource  : Boolean;  // Hat einen Quellen Dialog
    function  GetHasVideoOverlay: Boolean;  // Kann Overlay
    procedure Setoverlay(value:boolean);  // Setzen oder lschen des Overlaymodus
    procedure SetPreview(value:boolean);  // Setzen oder Lschen des Overlaymodus
    procedure SetScale(value:Boolean);   // Setzen oder Lschen des Scalflags
    procedure SetpreviewRate(value:word); // Setzen der Previewrate
    function GetCapInProgress:boolean;    //
    procedure SetIndexSize(value:cardinal);
// Setting callbacks as events
    procedure SetStatCallBack(value:TCapStatusCallback);
    procedure SetCapVideoStream(value:TVideoStream);
    procedure SetCapAudioStream(value:TAudioStream);

  public
    constructor Create(AOwner: TComponent); override;
    destructor destroy; override;

    property  HasDlgFormat:Boolean read GetHasDlgVFormat;    // hat Treiber einen Formatdialog
    property  HasDlgDisplay:Boolean read GetHasDlgVDisplay;  // hat Treiber einen Displaydialog
    property  HasDlgSource:Boolean read GetHasDlgVSource;    // Hat Treiner einen QuellenDialog
    property  HasVideoOverlay:boolean read GetHasVideoOverlay;  // Kann der Teiber VideoOverlay
    property  CapWidth: word read GetCapWidth;                  // Breite des capturebildes
    property  CapHeight: word read GetCapHeight;                // Hhe des Capturebildes
    property  CapInProgess: boolean read getCapinProgress;         // Capture Luft
    function DlgVFormat:Boolean;  // Aufruf Dialog VideoFormat
    function DlgVDisplay:boolean; // Aufruf Dialog VideoDisplay
    function DlgVSource:boolean;  // Aufruf Dialog VideoSource
    function DlgVCompression:Boolean; // Aufruf Dialog VideoCompression
    function GrabFrame:boolean;                                 // einzelnes Bild mit von Preview und Overlay
    function GrabFrameNoStop:boolean;                           // s.o Ohne Stop
    function SaveAsDIB:Boolean;                                 // Als DIB Speichern
    function SaveToClipboard:Boolean;                           // Ins Clipboard speichern
    function StartCapture:Boolean;                              // Capture Starten
    function StopCapture:Boolean;                               // Capture Stoppen;


 published
   property align;
   property DriverOpen: boolean read getDriveropen write setDriverOpen;
   property DriverIndex:integer read fdriverindex write SetDriverIndex;      // Treiberindex
   property DriverName: string read fVideoDriverName write SetDrivername;    // Treiber Name
   property VideoOverlay:boolean read GetOverlay write SetOverlay;   // Video Overlay anzeigen
   property VideoPreview:boolean read GetPreview write SetPreview;  // Video Preview anzeigen
   property PreviewScaleToWindow:boolean read fscale write Setscale;
   property PreviewScaleProportional:boolean read  fprop write Setprop;
   property PreviewRate:word read fpreviewrate write SetpreviewRate;
   property MicroSecPerFrame:cardinal read  fmicrosecpframe write SetMicroSecPerFrame;
   property FrameRate:word read  getFramerate write setFrameRate;
   Property CapAudio:Boolean read fcapAudio write fcapAudio;
   property VideoFileName:string read fCapVideoFileName   write fCapVideoFileName  ;
   property SingleImageFile:string read FCapSingleImageFileName write FCapSingleImageFileName;
   property CapTimeLimit:word read fCapTimeLimit write fCapTimeLimit;
   property CapIndexSize:cardinal read findexSize write setIndexSize;
   property CapToFile:boolean read fcaptoFile write fcapToFile;

   property OnStatus:TCapStatusProc read fCapStatusProcedure write FCapStatusProcedure;
   property OnStatusCallback:TCapStatusCallback read fcapStatuscallback write SetStatCallback;
   property OnVideoStream:TVideoStream read fcapVideoStream write SetCapVideoStream;
   property OnAudioStream:TAudioStream read fcapAudioStream write SetCapAudioStream;
  end;

procedure Register;

Function GetDriverList:TStringList;  // Liste mit allen auf dem Rechner verfgbaren Treibern


implementation


// Callback for status of video captures
function StatusCallbackProc(hWnd : HWND; nID : Integer; lpsz : Pchar): LongInt; stdcall;
var Control:TVideo;
begin
  control:=TVideo(capGetUserData(hwnd));
  if assigned(control) then
   begin
       if assigned(control.fcapStatusCallBack) then
              control.fcapStatusCallBack(control,nId,strPas(lpsz));
   end;
  result:= 1;
end;

// Callback for video stream
function VideoStreamCallbackProc(hWnd:Hwnd; lpVHdr:PVIDEOHDR):longint; stdcall;
 var Control:TVideo;
begin
  control:= TVideo(capGetUserData(hwnd));
  if assigned(control) then
   begin
    if assigned(control.fcapVideoStream ) then
         control.fcapVideoStream(control,lpvHdr);
   end;
 result:= 1;
end;

// Callback for audio stream
function AudioStreamCallbackProc(hwnd:HWND;lpWHdr:PWaveHdr):longInt; stdcall;
var control:TVideo;
begin
 control:= TVideo(capGetUserData(hwnd));
 if assigned(control) then
  if assigned(control.fcapAudioStream) then
    begin
     control.fcapAudioStream(control,lpwhdr);
    end;
 result:= 1;
end;


(*---------------------------------------------------------------*)
// Konstructor u Destructor
constructor TVideo.Create(aowner:TComponent);

begin
 inherited create(aowner);
 height                  := 100;
 width                   := 100;
 Color                   :=clblack;
 fVideoDriverName        := '';
 fdriverindex            := -1 ;
 fhCapWnd                := 0;
 fCapVideoFileName       := 'Video.avi';
 fCapSingleImageFileName := 'Capture.bmp';
 fscale                  := false;
 fprop                   := false;
 fpreviewrate            := 30;
 fmicrosecpframe     := 66667;
 fpDrivercaps            := nil;
 fpDriverStatus          := nil;
 fcapToFile              := true;

 fCapStatusProcedure     := nil;
 fcapStatusCallBack      := nil;
 fcapVideoStream         := nil;
 fcapAudioStream         := nil;

end;

 destructor TVideo.destroy;
  begin
    DestroyCapWindow;
    deleteDriverProps;
    inherited destroy;
  end;



(*---------------------------------------------------------------*)
// Meldungsbehandlung  zur Grenanpassung
 procedure TVideo.SetSize(var msg:TMessage);
  begin
  if (fhCapWnd <> 0) and (Fscale) then
    begin
     if msg.msg = WM_SIZE then SizeCap;
    end;
  end;

 procedure TVideo.SizeCap;
 var h,w:integer;
     f,cf:single;
 begin
  if not fscale then
      MoveWindow(fhcapWnd,0,0,Capwidth,capheight,true)
    else
      begin
       if fprop then
        begin
        f:= Width/height;
        cf:= CapWidth/CapHeight;
        if f >  cf then
         begin
          h:= height;
          w:= round(h*cf);
         end
        else
          begin
          w:= width;
          h:= round(w*1/cf);
         end
        end
       else
        begin
         h:= height;
         w:= Width;
       end;
       MoveWindow(fhcapWnd,0,0,w, h,true);
     end;
 end;


  (*---------------------------------------------------------------*)
// Treiberinfos Lschen
procedure TVideo.DeleteDriverProps;
 begin
   if assigned(fpDrivercaps) then
    begin
      dispose(fpDrivercaps);
      fpDriverCaps:= nil;
    end;
    if assigned(fpDriverStatus) then
     begin
       dispose(fpDriverStatus);
       fpDriverStatus:= nil;
     end;

 end;





(*---------------------------------------------------------------*)
// Fhigkeiten des Treibers abfragen

 function TVideo.GetDriverCaps:boolean;
 var savestat : integer;

 begin
   result:= false;
   if assigned(fpDrivercaps) then
     begin
       result:= true;
       exit;
     end;
   if fdriverIndex = -1 then exit;
   savestat := fhCapwnd;  // Fenstestaus sichern
   if fhCapWnd = 0 then CreateCapWindow;
   if fhCapWnd = 0 then exit;
   new(fpDrivercaps);
   if capDriverGetCaps(fhCapWnd, fpDriverCaps, sizeof(TCapDriverCaps)) then
    begin
     result:= true;
     if savestat = 0 then destroyCapWindow;
     exit;
    end;
   dispose(fpDriverCaps);  // Fehlgeschlagen
   fpDriverCaps := nil;
   if savestat = 0 then destroyCapWindow;
 end;
(*---------------------------------------------------------------*)
// Treiberstatus abfragen

function TVideo.getDriverStatus(callback:boolean):boolean;
begin
  result := false;
  if fhCapWnd <> 0 then
  begin
  if not assigned(fpDriverstatus) then new(fpDriverStatus);
  if capGetStatus(fhCapWnd,fpdriverstatus, sizeof(TCapStatus)) then
   begin
     result:= true;
  end;
  end;
 if assigned(fCapStatusProcedure)and callback then fcapStatusProcedure ( self);
end;



(*---------------------------------------------------------------*)
// Treibername Setzen

procedure TVideo.SetDrivername(value:string);
var i:integer;
    name:array[0..80] of char;
    ver :array[0..80] of char;
begin
 if fVideoDrivername = value then exit;
 for i:= 0 to 9 do
  if capGetDriverDescription( i,name,80,ver,80) then
    if strpas(name) = value then
     begin
      fVideoDriverName := value;
      Driverindex:= i;
      exit;
    end;
 fVideoDrivername:= '';
 DriverIndex:= -1;
end;
(*---------------------------------------------------------------*)
procedure TVideo.SetDriverIndex(value:integer);
var  name:array[0..80] of char;
     ver :array[0..80] of char;
begin
  if value = fdriverindex then exit;
  destroyCapWindow;
  deleteDriverProps;  // Alte Treiberfhigkeiten Lschen
  if value > -1 then
    begin
     if capGetDriverDescription(value,name,80,ver,80) then
        fVideoDriverName:= StrPas(name)
     else
       value:= -1;
   end;
 if value = -1 then  fvideoDriverName:= '';
 fdriverindex:= value;
end;
(*---------------------------------------------------------------*)
function TVideo.CreateCapWindow;

 begin
   if fhCapWnd <> 0 then
     begin
      result:= true;
      exit;
    end;
    result:= false;
   if fdriverIndex = -1 then
    begin
     MessageDlg('Kein Videocapturetreiber ausgewhlt',mterror,[mbok],0);
     GetDriverStatus(true);
     exit;
    end;
   fhCapWnd := capCreateCaptureWindow( PChar(Name),
              WS_CHILD or WS_VISIBLE , 0, 0,
               Width, Height,
              Handle, 5001);
   if fhCapWnd =0 then
     begin
       MessageDlg('Kann Capture Window nicht erzeugen',mterror,[mbOK],0);
       GetDriverStatus(true);
       exit;
      end;
  capSetUserData(fhCapwnd,integer(self));
// Setting callbacks as events
if assigned(fcapStatusCallBack ) then
  capSetCallbackOnStatus(fhcapWnd ,StatusCallbackProc);
if assigned(fcapVideoStream) then
   capSetCallbackOnVideoStream(fhcapwnd,VideoStreamCallbackProc);
if assigned(fcapAudioStream) then
       capSetCallbackOnWaveStream(fhcapWnd,AudioStreamCallbackProc);

 if not capDriverConnect(fhCapWnd, fdriverIndex) then
     begin
       MessageDlg('Kann Treiber nicht mit Fenster verbinden',mterror,[mbOK],0);
       Destroycapwindow;
       GetDriverStatus(true);
      end;
 capPreviewScale(fhCapWnd, fscale);
 capPreviewRate(fhCapWnd, round( 1/fpreviewrate*1000));
 GetDriverStatus(true);
 Sizecap;
 result:= true;
end;

// Setting callbacks as events

procedure TVideo.SetStatCallBack(value:TCapStatusCallback);
begin
 fcapStatusCallBack := value;
 if DriverOpen then
   if assigned(fcapStatusCallBack) then
      capSetCallbackOnStatus(fhcapWnd ,StatusCallbackProc)
   else
    capSetCallbackOnStatus(fhcapWnd ,nil);
end;


procedure TVideo.SetCapVideoStream(value:TVideoStream);
 begin
  fcapVideoStream:= value;
  if DriverOpen then
   if assigned(fcapVideoStream) then
     capSetCallbackOnVideoStream(fhcapwnd,VideoStreamCallbackProc)
   else
    capSetCallbackOnVideoStream(fhcapwnd, nil);
 end;

 procedure TVideo.SetCapAudioStream(value:TAudioStream);
  begin
   fcapAudioStream:= value;
    if DriverOpen then
     if assigned(fcapAudioStream) then
       capSetCallbackOnWaveStream(fhcapWnd,AudioStreamCallbackProc)
     else
      capSetCallbackOnWaveStream(fhcapWnd,nil);
  end;



(*---------------------------------------------------------------*)
procedure TVideo.DestroyCapWindow;
begin
  if fhCapWnd = 0 then exit;
  CapDriverDisconnect(fhCapWnd);
  DestroyWindow( fhCapWnd ) ;
  fhCapWnd := 0;
end;

(*---------------------------------------------------------------*)
function  TVideo.GetHasVideoOverlay:Boolean;

begin
   if getDriverCaps then
     Result := fpDriverCaps^.fHasOverlay
   else
     result:= false;
 end;

(*---------------------------------------------------------------*)

function  TVideo.GetHasDlgVFormat:Boolean;
begin
  if getDriverCaps then
     Result := fpDriverCaps^.fHasDlgVideoFormat
   else
     result:= false;
end;

(*---------------------------------------------------------------*)
function  TVideo.GetHasDlgVDisplay : Boolean;

begin
  if getDriverCaps then
     Result := fpDriverCaps^.fHasDlgVideoDisplay
   else
     result:= false;
end;

(*---------------------------------------------------------------*)
function  TVideo.GetHasDlgVSource  : Boolean;
begin
  if getDriverCaps then
     Result := fpDriverCaps^.fHasDlgVideoSource
   else
     result:= false;
end;

(*---------------------------------------------------------------*)
function TVideo.DlgVFormat:boolean;
var    savestat : integer;
begin
   result:= false;
   if fdriverIndex = -1 then exit;
   savestat := fhCapwnd;
   if fhCapWnd = 0 then
        if not CreateCapWindow then exit;
   result :=capDlgVideoFormat(fhCapWnd);
   if result then GetDriverStatus(true);
   if savestat = 0 then destroyCapWindow;
   if result then
   begin
    Sizecap;
    Repaint;
  end;
 end;

(*---------------------------------------------------------------*)
function TVideo.DlgVDisplay:boolean;
var savestat : integer;
begin
   result:= false;
   if fdriverIndex = -1 then exit;
   savestat := fhCapwnd;
   if fhCapWnd = 0 then
       if not CreateCapWindow then exit;
   result:=capDlgVideoDisplay(fhCapWnd) ;
   if result then GetDriverStatus(true);
   if savestat = 0 then destroyCapWindow;
   if result then
   begin
    SizeCap;
    Repaint;
  end;
end;

(*---------------------------------------------------------------*)
function TVideo.DlgVSource:boolean;
var savestat : integer;

begin
 result:= false;
 if fdriverIndex = -1 then exit;
  savestat := fhCapwnd;
  if fhCapWnd = 0 then
   if not createCapWindow then exit;
  result:= capDlgVideoSource(fhCapWnd);
  if result then GetDriverStatus(true);
  if savestat = 0 then destroyCapWindow;
  if result then
  begin
   SizeCap;
   Repaint;
 end;
end;
(*---------------------------------------------------------------*)
function TVideo.DlgVCompression;
var savestat : integer;

begin
 result:= false;
 if fdriverIndex = -1 then exit;
  savestat := fhCapwnd;
  if fhCapWnd = 0 then
   if not createCapWindow then exit;
   result:=capDlgVideoCompression(fhCapWnd);
  if savestat = 0 then destroyCapWindow;
 end;


(*---------------------------------------------------------------*)
 // Single Frame Grabbling
 function TVideo.GrabFrame:boolean;
 begin
  result:= false;
  if not DriverOpen then exit;
  Result:= capGrabFrame(fhcapwnd);
  if result then GetDriverStatus(true);
 end;

 function TVideo.GrabFrameNoStop:boolean;
 begin
  result:= false;
  if not DriverOpen then exit;
  Result:= capGrabFrameNoStop(fhcapwnd);
  if result then GetDriverStatus(true);
 end;

 (*---------------------------------------------------------------*)
// Frame Speichern
function TVideo.SaveAsDIB:Boolean;
  var s:array[0..MAX_PATH] of char;
begin
   result:= false;
   if not DriverOpen then exit;
   result := capFileSaveDIB(fhcapwnd,strpCopy(s,fCapSingleImageFileName));
end;

function  TVideo.SaveToClipboard:boolean;
begin
 result:= false;
 if not Driveropen then exit;
 result:= capeditCopy(fhcapwnd);
end;


(*---------------------------------------------------------------*)

procedure TVideo.Setoverlay(value:boolean);
begin
 if value = GetOverlay then exit;
 if gethasVideoOverlay = false then
   begin
    MessageDlg('Treiber kann kein Overlay',mtError,[mbOK],0);
    exit;
   end;
 if value = true then
  begin
   if fhcapWnd = 0 then  CreateCapWindow;
   GrabFrame;
  end;

 capOverlay(fhCapWnd,value);
 GetDriverStatus(true);
 invalidate;
 end;

function TVideo.GetOverlay:boolean;
begin
 if fhcapWnd = 0 then result := false
 else
  result:= fpDriverStatus^.fOverlayWindow;
end;



(*---------------------------------------------------------------*)

procedure TVideo.SetPreview(value:boolean);
begin
 if value = GetPreview then exit;
 if value = true then
   if fhcapWnd = 0 then  CreateCapWindow;
 capPreview(fhCapWnd,value);
 GetDriverStatus(true);
 invalidate;
end;

function TVideo.GetPreview:boolean;
begin
 if fhcapWnd = 0 then result := false
 else
  result:= fpDriverStatus^.fLiveWindow;
end;



procedure TVideo.SetPreviewRate(value:word);
begin
 if value = fpreviewrate then exit;
 if value < 1 then value := 1;
 if value > 30 then value := 30;
 fpreviewrate:= value;
 if DriverOpen then capPreviewRate(fhCapWnd, round( 1/fpreviewrate*1000));
end;

(*---------------------------------------------------------------*)

 procedure TVideo.SetMicroSecPerFrame(value:cardinal);
 begin
  if value =  fmicrosecpframe then exit;
  if value < 33333 then value := 33333;
   fmicrosecpframe := value;
end;



procedure TVideo.setFrameRate(value:word);
begin
 if value =0 then value := 10;
  fmicrosecpframe:= round(1.0/value*1000000.0);
end;

function  TVideo.GetFrameRate:word;
begin
 if fmicrosecpFrame > 0   then
   result:= round(1./ fmicrosecpframe * 1000000.0)
else
  result:= 0;
end;


function TVideo.StartCapture;
var CapParms:TCAPTUREPARMS;
    name:array[0..MAX_PATH] of char;

 begin
   result := false;
   if not DriverOpen then exit;
   capCaptureGetSetup(fhCapWnd, @CapParms, sizeof(TCAPTUREPARMS));
   capFileSetCaptureFile(fhCapWnd,strpCopy(name, fCapVideoFileName));
   CapParms.dwRequestMicroSecPerFrame := fmicrosecpframe;
   CapParms.fLimitEnabled    := BOOL(FCapTimeLimit);
   CapParms.wTimeLimit       := fCapTimeLimit;
   CapParms.fCaptureAudio    := fCapAudio;
   CapParms.fMCIControl      := FALSE;
   CapParms.fYield           := TRUE;
   CapParms.vKeyAbort        := VK_ESCAPE;
   CapParms.fAbortLeftMouse  := FALSE;
   CapParms.fAbortRightMouse := FALSE;
   capCaptureSetSetup(fhCapWnd, @CapParms, sizeof(TCAPTUREPARMS));
   if CapToFile then
    result:= capCaptureSequence(fhCapWnd)
   else
    result := capCaptureSequenceNoFile(fhCapWnd);
   GetDriverStatus(true);
 end;


function TVideo.StopCapture;
begin
 result:=false;
 if not DriverOpen then exit;
 result:=CapCaptureStop(fhcapwnd);
 getDriverstatus(true);
end;

 procedure TVideo.SetIndexSize(value:cardinal);
  begin
   if value = 0 then
    begin
      findexSize:= 0;
      exit;
    end;
   if value < 1800 then value := 1800;
   if value > 324000 then value := 324000;
  findexsize:= value;

 end;


function TVideo.GetCapInProgress:boolean;
  begin
   result:= false;
   if not DriverOpen then exit;
   GetDriverStatus(false);
   result:= fpDriverStatus^.fCapturingNow ;
 end;
 (*---------------------------------------------------------------*)

Procedure TVideo.SetScale(value:boolean);

begin
 if value = fscale then  exit;
 fscale:= value;
 if DriverOpen then
   begin
    capPreviewScale(fhCapWnd, fscale);
    SizeCap;
   end;
 Repaint;
end;

Procedure TVideo.Setprop(value:Boolean);
begin
 if value = fprop then exit;
 fprop:=value;
 if DriverOpen then Sizecap;
 Repaint;
end;


(*---------------------------------------------------------------*)
function TVideo.GetCapWidth;

begin
 if assigned(fpDriverStatus) then
   result:= fpDriverStatus^.uiImageWidth
else
   result:= 0;
end;

function TVideo.GetCapHeight;

begin
 if assigned(fpDriverStatus) then
   result:= fpDriverStatus^.uiImageHeight
else
   result:= 0;
end;



(*---------------------------------------------------------------*)
 Procedure TVideo.SetDriverOpen(value:boolean);          // ffnen/ Schlieen  des Treibers
 begin
   if value = GetDriverOpen then exit;
   if value = false then DestroyCapWindow;
   if value = true then CreateCapWindow;
 end;


function TVideo.GetDriverOpen:boolean;                        // Treieber Geffnet ?
begin
 result := fhcapWnd <> 0;
end;


function TDriverEditor.GetAttributes:TPropertyAttributes;
begin
 result :=[paRevertable,paValueList];
end;


procedure TDriverEditor.GetValues(Proc: TGetStrProc);
var i:integer;
    name:array[0..80] of char;
    ver :array[0..80] of char;
    s:string;

begin
 for i:= 0 to 9 do
  begin
   if capGetDriverDescription( i,name,80,ver,80) then
      s:=strpas(name)
   else
      s:='' ;
   proc(s);
  end;

end;



function TDriverEditor.GetValue:string;
begin
 with Getcomponent(0) as TVideo do
   result:= fVideoDrivername;
end;



procedure TDriverEditor.SetValue(const Value: string);
begin
  with Getcomponent(0) as TVideo do
    SetDrivername( value) ;
  Modified;
end;


Function GetDriverList:TStringList;
var i:integer;
    name:array[0..80] of char;
    ver :array[0..80] of char;
begin
 result:= TStringList.Create;
 result.Capacity:= 10;
 result.Sorted:= false;
 for i:= 0 to 9 do
   if capGetDriverDescription( i,name,80,ver,80) then
      result.Add(StrPas(name)+ ' '+strpas(ver))
   else
      result.add('');

 end;





procedure Register;
begin
  RegisterComponents('Bildverarbeitung', [TVideo]);
  RegisterPropertyEditor(TypeInfo(string),TVideo,'DriverName',TDriverEditor);
end;

end.
